@@ -1,4 +1,4 @@
-vcr_c <- NULL
+vcr_c <- NULL # nocov start
 VCRHooks <- NULL
 request_matchers <- NULL
 request_ignorer <- NULL
@@ -10,7 +10,7 @@ vcr_cassettes <- NULL
 initialize_ivars <- function() {
   light_switch <<- new.env()
   light_switch$turned_off <<- FALSE
-  vcr_c$ignore_cassettes <<- FALSE
+  light_switch$ignore_cassettes <<- FALSE
   vcr_c$cassettes <<- list()
   vcr_c$linked_context <<- NULL
 
@@ -31,4 +31,4 @@ initialize_ivars <- function() {
   vcr_cassettes <<- new.env()
   # lots of things
   initialize_ivars()
-}
+} # nocov end
